# Table of Contents

- [obsolescence-risk-management-discover-prioritize-risks](<./obsolescence-risk-management-discover-prioritize-risks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 3: Discover and Prioritize Technology Obsolescence Risks](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks.md>)
  - [Identify Applications With Unaddressed Risks](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks/Identify-Applications-With-Unaddressed-Risks.md>)
  - [Prioritize Risks by Business Criticality](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks/Prioritize-Risks-by-Business-Criticality.md>)
  - [Monitor Risks Over Time](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks/Monitor-Risks-Over-Time.md>)
  - [Next Step](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks/Next-Step.md>)
  - [Was this page helpful?](<./Step-3-Discover-and-Prioritize-Technology-Obsolescence-Risks/Was-this-page-helpful.md>)
